# Define Input Variables
# 1. Azure Location (CentralUS)
# 2. Azure Resource Group Name 
# 3. Azure AKS Environment Name (Dev, QA, Prod)

# Azure Location
variable "location" {
  type = string
  description = "Azure Region where all these resources will be provisioned"
  default = "westus2"
}

# Azure Resource Group Name
variable "resource_group_name" {
  type = string
  description = "This variable defines the Resource Group"
  default = "aks-foresight"
}

# Azure AKS Environment Name
variable "environment" {
  type = string  
  description = "This variable defines the Environment"  
  default = "dev"
}


resource "tls_private_key" "example" {
  algorithm = "RSA"
  rsa_bits  = 4096
}
resource "local_file" "ssh_public_key" {
  content  = tls_private_key.example.public_key_openssh
  filename = "${path.module}/aksprodsshkey.pub"
}

resource "local_file" "ssh_private_key" {
  content  = tls_private_key.example.private_key_pem
  filename = "${path.module}/aksprodsshkey.pem"
}

resource "null_resource" "move_ssh_keys" {
  provisioner "local-exec" {
    command = <<EOT
      mv ${local_file.ssh_public_key.filename} $HOME/.ssh/aks-prod-sshkeys-terraform/aksprodsshkey.pub
      mv ${local_file.ssh_private_key.filename} $HOME/.ssh/aks-prod-sshkeys-terraform/aksprodsshkey.pem
    EOT
  }

  depends_on = [local_file.ssh_public_key, local_file.ssh_private_key]
}
# Windows Admin Username for k8s worker nodes
variable "windows_admin_username" {
  type = string
  default = "azureuser"
  description = "This variable defines the Windows admin username k8s Worker nodes"  
}

# Windows Admin Password for k8s worker nodes
variable "windows_admin_password" {
  type = string
  default = "Foresight@123" 
  description = "This variable defines the Windows admin password k8s Worker nodes"  
}

